@@ -17,9 +17,10 @@
 
 
 #include	"utils.h"
+#include	<Multiprocessing.h>
 
 int
-numofcpu()
+_numofcpu()
 {
-	return 1;
+	return MPProcessors();
 }
