@@ -25,7 +25,8 @@
 #ifndef DEADLOCK_CHECK
 typedef struct _sem {
 	HTID		tid;
-	sem_t		ss;
+
+	pthread_mutex_t	mx;
 
 	char *		lock_file;
 	int		lock_line;
