@@ -40,7 +40,7 @@ aboat_resolve_request_init()
 	sigaction(SIGALRM, &sa, NULL);
 }
 
-
+/*
 void
 aboat_resolve_request()
 {
@@ -52,3 +52,19 @@ HTID tid;
 			pthread_kill((pthread_t)tid.tid, SIGALRM);
 	}
 }
+*/
+
+void
+res_abort(void * d)
+{
+HTID *tid;
+	if ( d == 0 )
+		return;
+	tid = (HTID*)d;
+	if ( tid->valid == 0 )
+		return;
+	pthread_kill((pthread_t)tid->tid, SIGALRM);
+	
+}
+
+
