@@ -37,6 +37,8 @@ void ufr_close_all();
 int ignore_child_flag;
 void init_posix_dependent();
 void (*thread_init_func)(int);
+int sigint_handler_glue();
+
 
 #define DTI_LENGTH		10000
 
@@ -184,6 +186,7 @@ int i;
 	set_alarm_mask(flags);
 	init_thread_block();
 	sw_init();
+	int_handler_glue = sigint_handler_glue;
 
 	task_lock = xx_new_lock(LL_TASK,__FILE__,__LINE__);
 	_lock_task(task_lock,__FILE__,__LINE__);
@@ -407,6 +410,37 @@ int * ptr;
 	return ret;
 }
 
+void
+sigint_handler_task(_TKEY d)
+{
+int data;
+
+	pthread_setcancelstate(PTHREAD_CANCEL_DISABLE,0);
+	set_alarm_mask(INI_DONTWAITCHI);
+	if ( (task_flags&INI_THREAD) == INI_DONTWAITCHI )
+		set_ignore_chld();
+
+	data = _GET_TKEY(d);
+	if ( int_handler ) {
+		if ( (*int_handler)() < 0 )
+			goto end;
+		pthread_detach((pthread_t)pthread_self());
+		pthread_exit(0);
+		return;
+	}
+end:
+	printf("Interrupted %i\n",(int)getpid());
+	exit(1);
+}
+
+int
+sigint_handler_glue()
+{
+
+	_create_task(sigint_handler_task,0,0);
+	return 0;
+}
+
 /*
 void
 rw_lock_init(RW_LOCK * rwl,int level)
