@@ -35,6 +35,28 @@ exit_stabilizer(char ch)
 	close(stab[1]);
 }
 
+
+void
+close_std()
+{
+int dpipe[2];
+	close(0);
+	pipe(dpipe);
+	if ( dpipe[0] == 0 )
+		close(dpipe[1]);
+	else	close(dpipe[0]);
+	close(1);
+	pipe(dpipe);
+	if ( dpipe[0] == 1 )
+		close(dpipe[1]);
+	else	close(dpipe[0]);
+	close(2);
+	pipe(dpipe);
+	if ( dpipe[0] == 2 )
+		close(dpipe[1]);
+	else	close(dpipe[0]);
+}
+
 int
 stabilizer()
 {
@@ -43,12 +65,10 @@ int ret;
 int id;
 int er;
 
+
 	all_signal_mask_posix();
 	set_ignore_chld();
 	ret = 's';
-	close(0);
-	close(1);
-	close(2);
 	for ( ; ; ) {
 		pipe(stab);
 		id = fork();
@@ -58,6 +78,7 @@ int er;
 			return ret;
 		}
 		close(stab[1]);
+		close_std();
 	retry:
 		if ( (er=read(stab[0],&ch,1)) == 1 ) {
 			switch ( ch ) {
