@@ -42,6 +42,7 @@ UFR_TBL * ufr_dispatch;
 int open_err_sub_code;
 int open_err_main_code;
 int u_open_point;
+int ufr_errno;
 
 U_FD_DEBUG *	fdd_list;
 
@@ -163,6 +164,7 @@ UFR_ERR e;
 int uid;
 int er;
 int err;
+int ret;
 	tbl = ufr_dispatch;
 
 	if ( tbl && ( (flags&RW_MODE) != O_RDONLY ) ) {
@@ -208,7 +210,9 @@ int err;
 	u_open_point = 5;
 dm:
 
-	return open(filename,flags,mode);
+	ret = open(filename,flags,mode);
+	ufr_errno = errno;
+	return ret;
 }
 
 
@@ -459,6 +463,7 @@ UFR_ARGS argv[1];
 UFR_ERR e;
 int uid;
 int err;
+
 	tbl = ufr_dispatch;
 	if ( tbl ) {
 		if ( (*tbl->fns.check_own)(&err,&uid,path) < 0 )
