@@ -731,4 +731,8 @@ void
 u_exit(int a)
 {
 	exit(a);
-}
\ No newline at end of file
+}
+
+void
+throw_signal(int tid,int sig)
+{}
\ No newline at end of file
