@@ -30,6 +30,7 @@
 #include "XPStyle.h"
 #include "v/VChooseFile.h"
 #include "v/vobj_utils.h"
+#include "v/v.h"
 
 #include <commdlg.h>
 #include <CdErr.h>
@@ -41,6 +42,8 @@ extern "C" {
 #include "memory_debug.h"
 
 bool idle_task();
+extern MAIN_WINDOWS *main_windows;
+int finish_by_close_last_window;
 }
 
 VWindowsList *windows_list;
@@ -331,6 +334,8 @@ VWindow::create_do(const VObjectStatus *s, int flags, VObject *parent, void * ar
 void
 VWindow::destroy_do(VObject *parent)
 {
+	MAIN_WINDOWS *mw,*prev;
+	
 	delete_window_list();
 	VCustomizedMenuBar::menu_lock(__FILE__,__LINE__);
 	if ( menu_bar ) {
@@ -347,7 +352,24 @@ VWindow::destroy_do(VObject *parent)
 		delete info;
 		info = NULL;
 	}
+	
+	prev = 0;
 
+	for(mw = main_windows; mw; prev=mw, mw= mw->next){
+		if(this == mw->win){
+			if(prev){
+				prev->next = mw->next;
+			}
+			else{
+				main_windows = mw->next;
+			}
+			d_f_ree(mw);
+			if((!main_windows) && finish_by_close_last_window ){
+				vobject_quit();
+			}
+			break;
+		}
+	}
 }
 
 VWindow::~VWindow()
@@ -697,3 +719,11 @@ VWindow::delete_window_list() {
 	wlist_prev->wlist_next = wlist_next;
 	VCustomizedMenuBar::menu_unlock(__FILE__,__LINE__);
 }
+
+VCustomizedMenuBar *
+VWindow::get_menu_bar()
+{ 
+	return menu_bar;
+}
+
+
