@@ -89,6 +89,14 @@ int ret;
 	return ret;
 }
 
+void
+cw_sexp(CREATE_WORK * cw,XL_SEXP * s)
+{
+XL_SEXP * r;
+	r = get_env_symbol(cw->env,l_string(std_cm,".phase"),-1);
+	set_env(cw->env,l_string(std_cm,".phase"),cons(s,r));
+}
+
 XL_SEXP *
 gb_gmxPhase(XLISP_ENV * env,XL_SEXP * s,XLISP_ENV * a,XL_SYM_FIELD * sf)
 {
@@ -168,6 +176,7 @@ int _no;
 			if ( cw->active_phase_mode >= 0 ) {
 				cw->phase_active[cw->active_phase_mode] = 1;
 				cw->phase[cw->active_phase_mode][_no] = s;
+				cw_sexp(cw,s);
 			}
 		}
 	}
@@ -205,6 +214,7 @@ int _no;
 				return s;
 			cw->phase_active[_mode] = 1;
 			cw->phase[_mode][_no] = s;
+			cw_sexp(cw,s);
 		}
 	}
 	return 0;
@@ -824,6 +834,7 @@ char * err_msg;
 	set_env(e,l_string(std_cm,"____gc_bind"),0);
 	cw.mtx = m;
 	set_env_work(e,&cw);
+	cw.env = e;
 	for ( s = cdr(s) ; get_type(s) == XLT_PAIR ; s = cdr(s) ) {
 		ret = eval(e,car(s));
 		if ( get_type(ret) == XLT_ERROR )
