@@ -911,7 +911,7 @@ FAVT_ROOT * rt;
 int ret;
 	h = 0;
 	encoding = l_string(std_cm,"UCS4");
-	p = open_filespace(
+	p = l_open_filespace(
 		n_string(std_cm,resource_cache.path),
 		O_CREAT|O_RDWR|O_TRUNC,0644,
 		PF_USEFREELIST,FT_RT_CACHE,encoding,0,0);
@@ -1128,12 +1128,12 @@ unsigned int fofs;
 int retry_cnt;
 	retry_cnt = 0;
 retry:
-	rs_p = open_filespace(
+	rs_p = l_open_filespace(
 		n_string(std_cm,resource_cache.path),O_RDWR,
 		0600,PF_USEFREELIST,FT_RT_CACHE,0,0,0);
 	if ( rs_p ) {
 		fofs = 0;
-		h = get_file_record(&fofs,
+		h = l_get_file_record(&fofs,
 			rs_p,PNT_RS_CACHE_HEADER);
 		if ( h == 0 ) {
 			l_close_filespace(rs_p);
