@@ -31,7 +31,12 @@
 #include	"rs_cache.h"
 #include	"rcache.h"
 #include	"save_global.h"
+#include	"avt.h"
 #define HANDLING_MAX		2
+/*
+#define RESOURCE_DEBUG
+#define RESOURCE_DEBUG_2
+*/
 
 extern SEM res_lock;
 extern GV_FUNC gv_new_table[RT_MAX];
@@ -39,6 +44,8 @@ extern XLISP_ENV * gv_resource_env[RT_MAX];
 
 SYS_QUEUE res_q0,res_q1,res_q2,res_lp1,res_disposer,res_extend;
 LOAD_RESOURCE_WORK * first_list;
+int first_list_cnt;
+AVT_NODE * first_list_tree;
 
 void _load_resource_task0(TKEY d);
 void _load_resource_task1(TKEY d);
@@ -66,23 +73,7 @@ RESOURCE_TYPE_LIST res_type_list[] = {
 void gc_lrw();
 void gc_lrw_get();
 void gc_gb_sexp();
-void resource_global();
-
-
-void
-resource_global()
-{
-	SG_TITLE;
-
-	sg("SEM",	"res_lock",	&res_lock);
-	sg("SYS_QUEUE",	"res_q0",	&res_q0);
-	sg("SYS_QUEUE",	"res_q1",	&res_q1);
-	sg("SYS_QUEUE",	"res_q2",	&res_q2);
-	sg("SYS_QUEUE",	"res_lp1",	&res_lp1);
-	sg("SYS_QUEUE",	"res_disposer",	&res_disposer);
-	sg("SYS_QUEUE",	"res_extend",	&res_extend);
-	sg("LOAD_RESOURCE_WORK","first_list",&first_list);
-}
+void monitor_tick(int);
 
 void
 init_load_resource()
@@ -96,7 +87,7 @@ init_load_resource()
 	res_extend.gc_func = gc_lrw;
 	res_extend.gc_get = gc_lrw_get;
 	res_extend.key_func = _lr_extend_task1;
-	res_extend.pri = PRI_FETCH;
+	res_extend.pri = PRI_FETCH_STRONG;
 	setup_queue(&res_extend);
 
 	memset(&res_q0,0,sizeof(SYS_QUEUE));
@@ -112,7 +103,7 @@ init_load_resource()
 	res_q1.gc_func = gc_lrw;
 	res_q1.gc_get = gc_lrw_get;
 	res_q1.key_func = _load_resource_task1;
-	res_q1.pri = PRI_FETCH;
+	res_q1.pri = PRI_FETCH_STRONG;
 	setup_queue(&res_q1);
 
 	memset(&res_q2,0,sizeof(SYS_QUEUE));
@@ -120,7 +111,7 @@ init_load_resource()
 	res_q2.gc_func = gc_lrw;
 	res_q2.gc_get = gc_lrw_get;
 	res_q2.key_func = _load_resource_task2;
-	res_q2.pri = PRI_FETCH;
+	res_q2.pri = PRI_FETCH_STRONG;
 	res_q2.total_limit = 4;
 	setup_queue(&res_q2);
 /*
@@ -137,23 +128,37 @@ init_load_resource()
 	res_lp1.gc_func = gc_lrw;
 	res_lp1.gc_get = gc_lrw_get;
 	res_lp1.key_func = _lr_extend_task2;
-	res_lp1.pri = PRI_FETCH;
+	res_lp1.pri = PRI_FETCH_STRONG;
 	setup_queue(&res_lp1);
 
 	memset(&res_disposer,0,sizeof(SYS_QUEUE));
 	res_disposer.flags = QF_FIFO;
 	res_disposer.gc_func = gc_lrw;
 	res_disposer.gc_get = gc_lrw_get;
-	res_disposer.pri = PRI_FETCH;
+	res_disposer.pri = PRI_FETCH_STRONG;
 	setup_queue(&res_disposer);
 
-	create_task(resource_disposer_task,0,PRI_FETCH);
+	create_task((void(*)(TKEY))resource_disposer_task,0,PRI_FETCH);
 
-	resource_global();
+#ifdef RESOURCE_DEBUG
+	new_tick(monitor_tick,10,10);
+#endif
 
 }
 
 
+void
+monitor_tick(int a)
+{
+	ss_printf("RES MON\n");
+	ss_printf("  res_disposer %i < %i\n",res_disposer.total_cnt,res_disposer.total_limit);
+	ss_printf("  res_lp1 %i < %i\n",res_lp1.total_cnt,res_lp1.total_limit);
+	ss_printf("  res_q2 %i < %i\n",res_q2.total_cnt,res_q2.total_limit);
+	ss_printf("  res_q1 %i < %i\n",res_q1.total_cnt,res_q1.total_limit);
+	ss_printf("  res_q0 %i < %i\n",res_q0.total_cnt,res_q0.total_limit);
+	ss_printf("  res_extend %i < %i\n",res_extend.total_cnt,res_extend.total_limit);
+}
+
 void
 _gc_lrw(LOAD_RESOURCE_WORK * w)
 {
@@ -371,8 +376,10 @@ RES_PARENT_LIST * p;
 		nos = 0;
 		for ( p = r->h.p_list ; p ; p = p->next , nos ++ ) {
 			insert_lw_service_code(&p->parent->h.auth_service_code,s,0);
-			if ( get_type(s) == XLT_ERROR && s->err.code == XLE_PROTO_PERMISSION_DENIED )
+			if ( get_type(s) == XLT_ERROR && s->err.code == XLE_PROTO_PERMISSION_DENIED ) {
 				p->parent->h.flags |= RF_PERMISSION;
+				r->h.flags |= RF_REQUIRED_PERMISSION;
+			}
 		}
 		lst = d_alloc(sizeof(RESOURCE*)*(nos+1));
 		i = 0;
@@ -383,7 +390,7 @@ RES_PARENT_LIST * p;
 	else {
 		insert_lw_service_code(&r->h.auth_service_code,s,0);
 		if ( get_type(s) == XLT_ERROR && s->err.code == XLE_PROTO_PERMISSION_DENIED )
-			r->h.flags |= RF_PERMISSION;
+			r->h.flags |= RF_PERMISSION|RF_REQUIRED_PERMISSION;
 		lst = d_alloc(sizeof(RESOURCE*)*2);
 		lst[0] = r;
 		lst[1] = 0;
@@ -490,6 +497,8 @@ LOAD_RESOURCE_WORK * w2;
 		free_url(&w->url);
 		if ( w->target )
 			d_f_ree(w->target);
+		if ( w->url_str )
+			d_f_ree(w->url_str);
 		free_lw_service_code(w->auth_service_code,0);
 		d_f_ree(w);
 	}
@@ -507,35 +516,49 @@ LOAD_RESOURCE_WORK * w2;
 		free_url(&w->url);
 		if ( w->target )
 			d_f_ree(w->target);
+		if ( w->url_str )
+			d_f_ree(w->url_str);
 		free_lw_service_code(w->auth_service_code,0);
 		d_f_ree(w);
 	}
 }
 
-LOAD_RESOURCE_WORK *
-_search_first_list(LOAD_RESOURCE_WORK * w)
+
+int
+_cmp_first_list(LOAD_RESOURCE_WORK * w1,LOAD_RESOURCE_WORK * w2)
 {
-LOAD_RESOURCE_WORK * wp;
-	for ( wp = first_list ; wp ; wp = wp->first_next )
-		if ( l_strcmp(get_url_str2(&w->url),
-				get_url_str2(&wp->url)) == 0 &&
-				w->option == wp->option )
-			return wp;
-	return 0;
+	return l_strcmp(w1->url_str,w2->url_str);
 }
 
+
 LOAD_RESOURCE_WORK *
 _search_first_list_by_url(L_CHAR * url,int opt)
 {
 LOAD_RESOURCE_WORK * wp;
 	for ( wp = first_list ; wp ; wp = wp->first_next )
-		if ( l_strcmp(url,
-				get_url_str2(&wp->url)) == 0 &&
+		if ( l_strcmp(url,wp->url_str) == 0 &&
 				opt == wp->option )
 			return wp;
 	return 0;
 }
 
+LOAD_RESOURCE_WORK *
+_search_first_list(LOAD_RESOURCE_WORK * w)
+{
+//LOAD_RESOURCE_WORK * wp;
+
+	if ( w->url_str == 0 )
+		w->url_str = ll_copy_str(get_url_str2(&w->url));
+	return _search_first_list_by_url(w->url_str,w->option);
+/*
+	for ( wp = first_list ; wp ; wp = wp->first_next )
+		if ( l_strcmp(get_url_str2(&w->url),
+				get_url_str2(&wp->url)) == 0 &&
+				w->option == wp->option )
+			return wp;
+	return 0;
+*/
+}
 void
 _delete_first_list(LOAD_RESOURCE_WORK * w)
 {
@@ -544,6 +567,10 @@ LOAD_RESOURCE_WORK ** wp;
 	for ( wp = &first_list ; *wp ; wp = &(*wp)->first_next )
 		if ( *wp == w ) {
 			*wp = w->first_next;
+			first_list_cnt --;
+#ifdef RESOURCE_DEBUG_2
+ss_printf("FL-DEL %i\n",first_list_cnt);
+#endif
 			return;
 		}
 
@@ -553,6 +580,12 @@ LOAD_RESOURCE_WORK ** wp;
 void
 _insert_first_list(LOAD_RESOURCE_WORK * w)
 {
+	first_list_cnt ++;
+#ifdef RESOURCE_DEBUG_2
+ss_printf("FL %i %ls\n",first_list_cnt,get_url_str2(&w->url));
+#endif
+	if ( w->url_str == 0 )
+		w->url_str = ll_copy_str(get_url_str2(&w->url));
 	w->first_next = first_list;
 	first_list = w;
 }
@@ -579,6 +612,22 @@ release_first_list(LOAD_RESOURCE_WORK * w)
 	unlock_task(res_lock,"release_first");
 }
 
+void
+purge_rcache_tick(int _g)
+{
+L_CHAR * g;
+	g = (L_CHAR*)_g;
+	purge_rcache(g);
+	d_f_ree(g);
+}
+
+void
+rcache_invoke_tick(int d)
+{
+	rcache_invoke();
+}
+
+
 void
 _res_end_op_extend(LOAD_RESOURCE_WORK * w,int err,RESOURCE * r,int clear)
 {
@@ -589,15 +638,17 @@ L_CHAR * f, * g;
 		f = get_url_str2(&w->url);
 		if ( f ) {
 			g = ll_copy_str(f);
-			purge_rcache(g);
-			d_f_ree(g);
+			new_tick(purge_rcache_tick,0,(int)g);
 		}
 	}
 	if ( r ) {
+#ifdef RESOURCE_DEBUG
+ss_printf("RESOURCE OK-1 %ls\n",get_url_str2(&r->h.entry));
+#endif
 		r->h.flags |= RF_LOAD_EXTEND;
 		r->h.flags &= ~(RF_LOAD_EXTEND_PROC|clear);
 		wakeup_task((int)r);
-		rcache_invoke();
+		new_tick(rcache_invoke_tick,0,0);
 	}
 	wakeup_task((int)w->wup);
 }
@@ -635,16 +686,18 @@ L_CHAR * f, * g;
 		f = get_url_str2(&w->url);
 		if ( f ) {
 			g = ll_copy_str(f);
-			purge_rcache(g);
-			d_f_ree(g);
+			new_tick(purge_rcache_tick,0,(int)g);
 		}
 	}
 	if ( r ) {
+#ifdef RESOURCE_DEBUG
+ss_printf("RESOURCE OK-2 %ls\n",get_url_str2(&r->h.entry));
+#endif
 		r->h.flags |= RF_COMPLETE;
 		if ( err < 0 )
 			r->h.flags |= RF_ERROR;
 		wakeup_task((int)r);
-		rcache_invoke();
+		new_tick(rcache_invoke_tick,0,0);
 	}
 	wakeup_task((int)w->wup);
 	_release_first_list(w);
@@ -671,14 +724,13 @@ L_CHAR * f,* g;
 		f = get_url_str2(&w->url);
 		if ( f ) {
 			g = ll_copy_str(f);
-			purge_rcache(g);
-			d_f_ree(g);
+			new_tick(purge_rcache_tick,0,(int)g);
 		}
 	}
 	if ( r ) {
 		r->h.flags |= RF_COMPLETE;
 		wakeup_task((int)r);
-		rcache_invoke();
+		new_tick(rcache_invoke_tick,0,0);
 	}
 	wakeup_task((int)w->wup);
 	_release_first_list(w);
@@ -775,12 +827,30 @@ LOAD_RESOURCE_WORK * ret;
 	ret->same_next = 0;
 	ret->same_list = 0;
 	ret->first_next = 0;
+	ret->url_str = 0;
 
 	ret->que_pri = 0;
 	return ret;
 }
 
 
+char *
+get_que_prefix(URL * u)
+{
+int len;
+	if ( u->resource == 0 )
+		return 0;
+	len = l_strlen(u->resource);
+	if ( len >= 4 && l_strcmp(&u->resource[len-4],l_string(std_cm,".map")) == 0 )
+		return ".map";
+	if ( len >= 4 && l_strcmp(&u->resource[len-4],l_string(std_cm,".vct")) == 0 )
+		return ".vct";
+	if ( len >= 4 && l_strcmp(&u->resource[len-4],l_string(std_cm,".lst")) == 0 )
+		return ".lst";
+	if ( len >= 4 && l_strcmp(&u->resource[len-4],l_string(std_cm,".crd")) == 0 )
+		return ".crd";
+	return 0;
+}
 
 
 void
@@ -795,7 +865,7 @@ L_CHAR * f;
 void gc_gb_sexp();
 XL_SEXP * query;
 LOAD_RESOURCE_WORK * wp,* target;
-
+char agent[50];
 
 	gc_push(0,0,"remote_fetch");
 
@@ -854,11 +924,12 @@ ss_printf("query ");
 print_sexp(s_stdout,query,0);
 ss_printf("\n");
 */
+	sprintf(agent,"gbstd#%i",data_flag);
 	w->_meta_ret = remote_session(
 		gblisp_top_env0,
 		ses,
 		&target->url,
-		0,
+		l_string(std_cm,agent),
 		l_string(std_cm,"user"),
 		l_string(std_cm,"Get"),
 		List(query,-1),
@@ -869,7 +940,7 @@ print_sexp(s_stdout,w->_meta_ret,0);
 ss_printf("\n");
 */
 	if ( w->h.key == 0 )
-		w->h.key = get_server_key(&target->url,0);
+		w->h.key = get_server_key(&target->url,get_que_prefix(&target->url));
 
 	insert_queue(q,w,wait_flag);
 end:
@@ -1013,8 +1084,9 @@ XL_SEXP * set_resource_header();
 XLISP_ENV * env;
 XL_SEXP * last_tag;
 COORDINATE_UNIT * cup;
-
-
+#ifdef RESOURCE_DEBUG_2
+INTEGER64 tim;
+#endif
 
 	gc_push(0,0,"_load_resource_list");
 
@@ -1195,7 +1267,19 @@ print_sexp(s_stdout,ret,0);
 ss_printf("\n");
 				goto err_end;
 			}
+//res_end_op(wp,LRWE_OK,wp->result);
+#ifdef RESOURCE_DEBUG_2
+ss_printf("EVAL-2 PR %i %ls\n",get_tid(),wp->h.key);
+tim = get_xltime();
+print_sexp(s_stdout,last_tag,0);
+ss_printf("\n");
+#endif
 			ret = eval(env,car(last_tag));
+#ifdef RESOURCE_DEBUG_2
+ss_printf("EVA-2L PR %i %ls " I64_FORMAT "\n",get_tid(),wp->h.key,get_xltime()-tim);
+print_sexp(s_stdout,ret,0);
+ss_printf("\n");
+#endif
 			if ( get_type(ret) == XLT_ERROR ) {
 ss_printf("ERROR BODY 1\n");
 print_sexp(s_stdout,rr->h.data,0);
@@ -1387,6 +1471,9 @@ XLISP_ENV * env;
 RS_BUF rsb;
 XL_SEXP * ret, * last_tag;
 L_CHAR * f;
+#ifdef RESOURCE_DEBUG_2
+INTEGER64 tim;
+#endif
 
 	que = (SYS_QUEUE *)GET_TKEY(d);
 	key = touch_qkey(que);
@@ -1397,6 +1484,10 @@ L_CHAR * f;
 	xli->a_type = XLA_SELF;
 	setup_i(xli);
 
+	if ( l_strcmp(&key[l_strlen(key)-4],l_string(std_cm,".vct")) == 0 )
+		change_pri(0,PRI_FETCH);
+
+
 
 	ses = open_session(SEST_OPTIMIZE);
 	for ( ; ; ) {
@@ -1405,7 +1496,7 @@ L_CHAR * f;
 		lock_task(res_lock);
 		unlock_task(res_lock,"_load_resource_task1");
 
-		wp = delete_queue(&res_q0,0,0,0);
+		wp = delete_queue(&res_q0,sq_key_cond,key,0);
 		if ( wp == 0 ) {
 			gc_pop(0,0);
 			break;
@@ -1421,15 +1512,15 @@ L_CHAR * f;
 			if ( get_rs_resource_cache(&rsb,
 					get_url_str2(&wp->url),
 					RSQ_RESOURCE|RSQ_DATA) < 0 ) {
-/*
+#ifdef RESOURCE_DEBUG_2
 ss_printf("GET EMPTY %ls\n",get_url_str2(&wp->url));
-*/
+#endif
 				insert_queue(&res_q1,wp,1);
 				break;
 			}
-/*
+#ifdef RESOURCE_DEBUG_2
 ss_printf("GET SUCCESS %x %ls\n",rsb.r,get_url_str2(&wp->url));
-*/
+#endif
 			if ( rsb.flags & RSBF_MAP ) {
 /*
 ss_printf("MAP--------\n");
@@ -1479,11 +1570,19 @@ ss_printf("MAP--------\n");
 ss_printf("--------- CACHE ERROR %i\n",rsb.r->h.type);
 print_sexp(s_stdout,wp->data_result,0);
 ss_printf("\n");
-print_sexp(s_stdout,ret,0);
+print_sexp(s_stdout,last_tag,0);
 ss_printf("\n");
 					break;
 				}
+#ifdef RESOURCE_DEBUG_2
+ss_printf("EVAL PR %i %ls\n",get_tid(),wp->h.key);
+tim = get_xltime();
+#endif
+
 				ret = eval(env,car(last_tag));
+#ifdef RESOURCE_DEBUG_2
+ss_printf("EVAL PR %i %ls " I64_FORMAT "\n",get_tid(),wp->h.key,get_xltime()-tim);
+#endif
 				if ( get_type(ret) == XLT_ERROR ) {
 ss_printf("ERROR BODY 2\n");
 print_sexp(s_stdout,rsb.data,0);
@@ -1550,7 +1649,15 @@ SYS_QUEUE * que;
 			gc_pop(0,0);
 			break;
 		}
-		_load_meta_list_insert(ses,&res_q2,"meta",1,wp,Q_WAIT_WAIT);
+		if ( wp->option == LRO_UNIT )
+			_load_meta_list_insert(ses,&res_q2,"meta",1,wp,Q_WAIT_WAIT);
+		else if ( l_strcmp(&wp->url.resource[l_strlen(wp->url.resource)-4],
+				l_string(std_cm,".vct")) == 0 )
+			_load_meta_list_insert(ses,&res_q2,"meta",2,wp,Q_WAIT_WAIT);
+		else if ( l_strcmp(&wp->url.resource[l_strlen(wp->url.resource)-4],
+				l_string(std_cm,".map")) == 0 )
+			_load_meta_list_insert(ses,&res_q2,"meta",3,wp,Q_WAIT_WAIT);
+		else	_load_meta_list_insert(ses,&res_q2,"meta",1,wp,Q_WAIT_WAIT);
 		gc_pop(0,0);
 	}
 
@@ -1583,6 +1690,8 @@ SYS_QUEUE * que;
 	xli->a_type = XLA_SELF;
 	setup_i(xli);
 
+	if ( l_strcmp(&key[l_strlen(key)-4],l_string(std_cm,".vct")) == 0 )
+		change_pri(0,PRI_FETCH);
 
 	ses = open_session(SEST_OPTIMIZE);
 	for ( ; ; ) {
@@ -1808,14 +1917,30 @@ int handling;
 
 	wp = w;
 	handling = 0;
-/*
+#ifdef RESOURCE_DEBUG
 ss_printf("IN (%i) - \n",get_tid());
-*/
+#endif
 	for ( ; wp ; wp = wp->req_next ) {
+	  	if ( wp->url.proto == 0 || wp->url.proto[0] == 0 ) {
+			wp->err = LRWE_ERROR_URL;
+			continue;
+		}
+		if ( wp->url.server == 0 || wp->url.server[0] == 0 ) {
+			wp->err = LRWE_ERROR_URL;
+			continue;
+		}
+		if ( wp->url.db == 0 || wp->url.db[0] == 0 ) {
+			wp->err = LRWE_ERROR_URL;
+			continue;
+		}
+		if ( wp->url.resource == 0 || wp->url.resource[0] == 0 ) {
+			wp->err = LRWE_ERROR_URL;
+			continue;
+		}
 		entry = get_url_str2(&wp->url);
-/*
+#ifdef RESOURCE_DEBUG
 ss_printf("IN (%i) %ls\n",get_tid(),entry);
-*/
+#endif
 		if ( entry == 0 ) {
 			wp->err = LRWE_ERROR_URL;
 			continue;
@@ -1830,7 +1955,7 @@ ss_printf("IN (%i) %ls\n",get_tid(),entry);
 			wp->err = LRWE_OK;
 		else 	wp->err = LRWE_HANDLING;
 		wp->que_pri = get_que_pri(&wp->url);
-		wp->h.key = get_server_key(&wp->url,0);
+		wp->h.key = get_server_key(&wp->url,get_que_prefix(&wp->url));
 		switch ( wp->option ) {
 		case 0:
 			break;
@@ -1863,9 +1988,9 @@ ss_printf("IN (%i) %ls\n",get_tid(),entry);
 	lock_task(res_lock);
 	if ( handling == 0 ) {
 		if ( wait_flag == 0 ) {
-/*
+#ifdef RESOURCE_DEBUG
 ss_printf("OUT (%i) NO WAIT\n",get_tid());
-*/
+#endif
 			unlock_task(res_lock,"load_resource_list");
 			return;
 		}
@@ -1879,9 +2004,9 @@ ss_printf("OUT (%i) NO WAIT\n",get_tid());
 			wp->err = LRWE_HANDLING;
 	}
 	if ( wait_flag == 0 ) {
-/*
+#ifdef RESOURCE_DEBUG
 ss_printf("OUT (%i) NO WAIT\n",get_tid());
-*/
+#endif
 		unlock_task(res_lock,"load_resource_list");
 		return;
 	}
@@ -1906,9 +2031,9 @@ slp2:
 		}
 	}
 	unlock_task(res_lock,"load_resource_list");
-/*
+#ifdef RESOURCE_DEBUG
 ss_printf("OUT (%i)\n",get_tid());
-*/
+#endif
 
 	return;
 }
@@ -2083,7 +2208,7 @@ LOAD_RESOURCE_WORK * wp;
 	wp->err = LRWE_HANDLING;
 	wp->wup_func = wup_func;
 	wp->result = r;
-	wp->h.key = get_server_key(&r->h.entry,0);
+	wp->h.key = get_server_key(&r->h.entry,get_que_prefix(&r->h.entry));
 	wp->que_pri = 0;
 	insert_queue(&res_extend,wp,1);
 	return 0;
