@@ -1087,7 +1087,7 @@ MP_ROUTE * ret,* new_r,* s;
 			free_copy_route(ret);
 			return s;
 		}
-		free_copy_route(s);
+		_delete_route(&direct,s);
 	}
 	new_r = _new_route(&direct);
 	new_r->head = ret->head;
@@ -1418,7 +1418,7 @@ MP_ROUTE * r1, * r2;
 			gblisp_top_env0,
 			ses,
 			&u,
-			l_string(std_cm,"gbstd"),
+			l_string(std_cm,"gbstd#route"),
 			l_string(std_cm,"user"),
 			l_string(std_cm,"Get"),
 			List(
@@ -2103,6 +2103,7 @@ LOAD_RESOURCE_WORK * w;
 			ret = _ret;
 		}
 	}
+
 	if ( w )
 		load_resource_list(w,Q_PRI_ROUTING,0);
 	return ret;
@@ -2372,6 +2373,7 @@ int ret_cnt;
 
 	ret_cnt = 3;
 retry:
+
 	ret = check_routing_table(org,target);
 	if ( ret != CRT_EXIST )
 		return ret;
