@@ -33,6 +33,8 @@
 #include	"machine/include.h"
 #include	"mx_format.h"
 #include	"pg_vector.h"
+#include	"pg_scale.h"
+#include	"pg_1dgraph.h"
 
 typedef struct pixel_req {
 	struct pixel_req *	next;
@@ -78,8 +80,11 @@ vmt_dummy(VIEW_METHOD* vm,GBVIEW_FLAME* gf,RESOURCE * r,DRAW_WORK* dw);
 
 extern VIEW_METHOD_TBL vm_plot_tbl;
 
+static int div_list[] = {-2,-2};
+
 VIEW_METHOD_TBL vm_rgb_tbl = {
-	MDT_RGB8|MDT_VECTOR,0,
+	MDT_RGB8|MDT_VECTOR,
+	2,div_list,0,
 	vmt_create_draw_pixel,
 	0,
 	draw_pixel_data_2,
@@ -89,6 +94,27 @@ VIEW_METHOD_TBL vm_rgb_tbl = {
 VIEW_METHOD_TBL * pixel_vm[] = {
 	&vm_rgb_tbl,
 	&vm_plot_tbl,
+	&vm_scale_tbl_int8,
+	&vm_scale_tbl_uint8,
+	&vm_scale_tbl_int16,
+	&vm_scale_tbl_uint16,
+	&vm_scale_tbl_int32,
+	&vm_scale_tbl_uint32,
+	&vm_scale_tbl_int64,
+	&vm_scale_tbl_uint64,
+	&vm_scale_tbl_float,
+	&vm_scale_tbl_double,
+
+	&vm_1dgraph_tbl_int8,
+	&vm_1dgraph_tbl_uint8,
+	&vm_1dgraph_tbl_int16,
+	&vm_1dgraph_tbl_uint16,
+	&vm_1dgraph_tbl_int32,
+	&vm_1dgraph_tbl_uint32,
+	&vm_1dgraph_tbl_int64,
+	&vm_1dgraph_tbl_uint64,
+	&vm_1dgraph_tbl_float,
+	&vm_1dgraph_tbl_double,
 	0
 };
 
@@ -106,6 +132,8 @@ XL_SEXP * gv_set_visible_resolution();
 			get_func_prim(gv_set_visible_resolution,
 			FO_APPLICATIVE,0,2,2));
 	init_pg_vector(luster_cmd);
+	init_pg_scale(luster_cmd);
+	init_pg_1dgraph(luster_cmd);
 next:
 /*
 	create_task(pixel_req_task,0,PRI_FETCH);
