@@ -31,6 +31,8 @@
 #include	"lump.h"
 #include	"acrp.h"
 
+#define USE_OPTIM_LUMP
+
 extern SYS_QUEUE mp_task_que;
 extern int max_hops;
 extern SEM tick_que_lock;
@@ -411,6 +413,8 @@ LUMP_ROUTE * lr3;
 		lr3 = search_lr(lr1,lr2->lump_crd);
 		if ( lr3 == 0 )
 			return lr2;
+		if ( lr3->version != lr2->version )
+			return lr2;
 	}
 	return 0;
 }
@@ -427,6 +431,8 @@ cmp_lr(LUMP_ROUTE * lr1,LUMP_ROUTE * lr2)
 			return -1;
 		if ( lr1->distance != lr2->distance )
 			return -1;
+		if ( lr1->version != lr2->version )
+			return -1;
 	}
 	if ( lr1 == 0 && lr2 == 0 )
 		return 0;
@@ -478,6 +484,7 @@ XL_SEXP * option;
 				get_integer(lr->pri,0),
 				get_integer(lr->distance,0),
 				get_integer(lr->radius,0),
+				get_integer(lr->version,0),
 				-1),
 			ret);
 	}
@@ -681,6 +688,67 @@ LUMP_ROUTE lr0;
 	return insert_lr(lr,&lr0,0,0);
 }
 
+int
+check_global(LUMP_ROUTE ** ret_target,LUMP_ROUTE * lr,URL * me)
+{
+LUMP_ROUTE * target[2];
+LUMP_ROUTE * lr_ptr;
+int other;
+URL u;
+int ret;
+	target[0] = target[1] = 0;
+	other = 0;
+	for ( lr_ptr = lr ; lr_ptr ; lr_ptr = lr_ptr->next ) {
+		get_url2(&u,lr_ptr->lump_crd);
+		if ( l_strcmp(u.server,me->server) == 0 &&
+					u.port == me->port ) {
+			if ( target[0] == 0 ) {
+				target[0] = lr_ptr;
+			}
+			else if ( target[1] == 0 ) {
+				if ( target[0]->pri <= lr_ptr->pri )
+					target[1] = lr_ptr;
+				else {
+					target[1] = target[0];
+					target[0] = lr_ptr;
+				}
+			}
+			else {
+				if ( lr_ptr->pri < target[0]->pri ) {
+					target[1] = target[0];
+					target[0] = lr_ptr;
+				}
+				else if ( lr_ptr->pri < target[1]->pri ) {
+					target[1] = lr_ptr;
+				}
+			}
+		}
+		else {
+			other ++;
+		}
+		free_url(&u);
+	}
+	ret = 0;
+	if ( other ) {
+		target[1] = 0;
+		if ( target[0] == 0 )
+			ret = 1;
+		else	ret = 0;
+	}
+	else {
+		if ( target[0] == 0 )
+			ret = 2;
+		else if ( target[1] == 0 )
+			ret = 1;
+		else	ret = 0;
+	}
+	ret_target[0] = target[0];
+	ret_target[1] = target[1];
+	return ret;
+}
+
+#ifndef USE_OPTIM_LUMP
+
 int
 check_launch(LUMP_ROUTE * lr,URL * me)
 {
@@ -705,8 +773,6 @@ LUMP_ROUTE * lrp;
 	return 0;
 }
 
-
-
 int
 destroy_check(LUMP_ROUTE * lr)
 {
@@ -758,6 +824,123 @@ int same,other;
 	return ret;
 }
 
+#endif
+
+
+#ifdef USE_OPTIM_LUMP
+
+
+int
+check_launch(LUMP_ROUTE * lr,URL * me)
+{
+LUMP_ROUTE * target[2];
+	if ( check_global(target,lr,me) )
+		return 1;
+	return 0;
+}
+
+
+int
+destroy_check(LUMP_ROUTE * lr)
+{
+URL me;
+LUMP_ROUTE * target[2];
+	if ( lr == 0 )
+		return 0;
+	if ( lr->distance )
+		return 0;
+	get_url2(&me,lr->lump_crd);
+	check_global(target,lr,&me);
+	if ( target[0] == lr )
+		return 0;
+	if ( target[1] == lr )
+		return 0;
+	return 1;
+}
+
+
+void
+intermediate_check(LUMP_ROUTE ** lr_org,URL * me)
+{
+LUMP_ROUTE * target[2];
+LUMP_ROUTE * lrp;
+LUMP_ROUTE ** lrp_p;
+URL u;
+XL_SEXP * lump_data;
+LUMP_OPT opt;
+L_CHAR* cc;
+LUMP_ROUTE * load_lr;
+L_CHAR * path;
+int fg;
+	if ( check_global(target,*lr_org,me) )
+		return;
+	for ( lrp_p = lr_org ; *lrp_p ; ) {
+		fg = 0;
+		lrp = *lrp_p;
+		get_url2(&u,lrp->lump_crd);
+		if ( !(l_strcmp(u.server,me->server) == 0 &&
+				u.port == me->port) ) {
+			goto loop;
+		}
+		if ( lrp == target[0] )
+			goto loop;
+		if ( lrp == target[1] )
+			goto loop;
+		if ( lrp->distance == 0 )
+			goto loop;
+		/* destroy mode */
+		
+		gc_push(0,0,"intermediate");
+		lump_data = local_fetch(0,&u,".lmp");
+		if ( get_type(lump_data) == XLT_ERROR )
+			goto err;
+		cc  = ll_copy_str(get_url_str2(&u));
+		init_lump_opt(&opt);
+		load_lr = get_lr(&opt,lump_data,cc);
+		d_f_ree(cc);
+		if ( opt.destroy )
+			goto err1;
+		if ( opt.lump == 0 )
+			goto err1;
+ss_printf("DESTROY %ls\n",get_url_str2(&u));
+/*
+		lr0 = load_lr;
+		load_lr =load_lr->next;
+		lr0->next = 0;
+		free_lr(lr0);
+		opt.destroy = 0;
+		if ( opt.lump )
+			d_f_ree(opt.lump);
+		opt.lump = 0;
+*/
+		opt.destroy = -1;
+		save_lr(&u,load_lr,&opt);
+		free_lr(load_lr);
+
+		path = get_url_filepath(&u);
+ss_printf("path = %ls\n",path);
+		insert_tick_que(0,
+				path,TQT_LMP,TQL_LUMP_HIGH);
+		d_f_ree(path);
+
+	err1:
+		*lrp_p = lrp->next;
+		lrp->next = 0;
+		free_lr(lrp);
+		fg = 1;
+		free_lump_opt(&opt);
+	err:
+		gc_pop(0,0);
+	loop:
+		free_url(&u);
+		if ( fg == 0 )
+			lrp_p = &(*lrp_p)->next;
+	}
+}
+
+#endif
+
+
 int
 check_loop_lump(LUMP_ROUTE ** lr)
 {
@@ -872,6 +1055,16 @@ LUMP_AROUND_LIST * a1;
 	}
 }
 
+int 
+lr_length(LUMP_ROUTE * lr)
+{
+int ret;
+	for ( ret = 0 ; lr ; lr = lr->next , ret ++ );
+	return ret;
+}
+
+
+
 void
 check_my_lump(int ses,L_CHAR * filename)
 {
@@ -926,6 +1119,8 @@ log_printf(LOG_DEBUG,LOG_LAYER_GB,0,"launch-lump main:0 %ls ERROR-RETRY-OK",file
 
 
 	lr = get_dist0(my_lr);
+	if ( lr )
+		lr->version = LUMP_VERSION;
 	for ( a1 = a ; a1 ; a1 = a1->next ) {
 		get_url2(&u2,a1->url);
 		gc_push(0,0,"check_my_lump");
@@ -967,7 +1162,7 @@ log_printf(LOG_DEBUG,LOG_LAYER_GB,0,"launch-lump %ls start-to-count-2",filename)
 			opt.flag = 1;
 		}
 	}
-	else if ( destroy_check(lr) ) {
+	else if ( destroy_check(lr) || opt.destroy == -1 ) {
 		if ( opt.destroy == 0 ) {
 			opt.destroy = get_xltime() + 
 				LUMP_DESTROY_MIN + 
@@ -976,7 +1171,7 @@ log_printf(LOG_DEBUG,LOG_LAYER_GB,0,"launch-lump %ls start-to-count-2",filename)
 			opt.flag = 1;
 log_printf(LOG_DEBUG,LOG_LAYER_GB,0,"launch-lump %ls start-to-count-destroy-1",filename);
 		}
-		else if ( opt.destroy <= get_xltime() ) {
+		else if ( opt.destroy == -1 || opt.destroy <= get_xltime() ) {
 			lr0 = lr;
 			lr = lr->next;
 			lr0->next = 0;
@@ -1031,6 +1226,9 @@ log_printf(LOG_DEBUG,LOG_LAYER_GB,0,"cannot open the lump path %s",path);
 		}
 	}
 	loop_ditect = check_loop_lump(&lr);
+#ifdef USE_OPTIM_LUMP
+	intermediate_check(&lr,&u1);
+#endif
 
 	lr = filter_lr(lr);
 	new_lr = check_new_lump(my_lr,lr);
@@ -1059,11 +1257,14 @@ log_printf(LOG_DEBUG,LOG_LAYER_GB,0,"cannot open the lump path %s",path);
 		lump_db_trigger(ses,a);
 	now = get_xltime();
 	if ( opt.destroy ) {
+		if ( opt.destroy == -1 )
+			insert_tick_que(0,
+				filename,TQT_LMP,TQL_LUMP_HIGH);
 		if ( now < opt.destroy )
 			insert_tick_que(opt.destroy-get_xltime(),
-				filename,TQT_LMP,TQL_LUMP);
+				filename,TQT_LMP,TQL_LUMP_HIGH);
 		else	insert_tick_que(0,
-				filename,TQT_LMP,TQL_LUMP);
+				filename,TQT_LMP,TQL_LUMP_HIGH);
 	}
 	if ( opt.launch ) {
 		if ( now < opt.launch )
