@@ -64,16 +64,17 @@ set_idle_interval(float p)
 {
 MP_WORK mpw;
 TQ_STATISTICS tqs;
-
+int _idle_interval;
 
 	get_mp_work(&mpw,0);
 	tick_que_statistics(&tqs);
 	mpw.total_maps = tqs.maps + get_map_nos();
-	idle_interval = 2*idle_interval*(1-p);
-	if ( idle_interval < mpw.total_maps*MAPPING_PING_INTERVAL_UNIT )
-		idle_interval = mpw.total_maps*MAPPING_PING_INTERVAL_UNIT;
-	if ( idle_interval < 10 )
-		idle_interval = 10;
+	_idle_interval = 2*idle_interval*(1-p);
+	if ( _idle_interval < mpw.total_maps*MAPPING_PING_INTERVAL_UNIT )
+		_idle_interval = mpw.total_maps*MAPPING_PING_INTERVAL_UNIT;
+	if ( _idle_interval < 10 )
+		_idle_interval = 10;
+	idle_interval = _idle_interval;
 	set_mp_work(&mpw);
 }
 
@@ -846,8 +847,8 @@ MP_WORK mpw;
 		next = 10;
 	if ( next < p_interval )
 		next = p_interval;
-	if ( next > 2*pmd_prev_interval )
-		next = 2*pmd_prev_interval;
+	if ( next > 1.5*pmd_prev_interval )
+		next = 1.5*pmd_prev_interval;
 	return next;
 }
 
@@ -1221,19 +1222,44 @@ int time;
 			org->pmd_interval);
 
 
+	if ( time > org->pmd_time ) {
+		if ( org->pmd_time - get_xltime() > 0 ) {
+			insert_tick_que(org->pmd_time-get_xltime(),ot->tq->filename,
+				TQT_MAP,TQL_NORMAL);
+			goto end;
+		}
+	}
+	else {
+		if ( time - get_xltime() > 0 ) {
+			insert_tick_que(time-get_xltime(),ot->tq->filename,
+				TQT_MAP,TQL_NORMAL);
+			goto end;
+		}
+	}
+
+	if ( org->pmd_interval > org->_interval )
+		ret = org->_interval;
+	else	ret = org->pmd_interval;
+	insert_tick_que(ret,ot->tq->filename,
+		TQT_MAP,TQL_NORMAL);
+	
+end:
+	free_mp_task_t(ot);
+
+/*
 	if ( org->pmd_interval > org->_interval )
 		ret = org->_interval;
 	else	ret = org->pmd_interval;
 	if ( ret - org->tat <= 0 )
 		ret = 1;
 	else	ret = ret - org->tat;
-/*
-ss_printf("PM LAST %ls %i\n",ot->tq->filename,mp_task_que.total_cnt);
-*/
+//ss_printf("PM LAST %ls %i\n",ot->tq->filename,mp_task_que.total_cnt);
+
 	if ( ret >= 0 )
 		insert_tick_que(org->interval,ot->tq->filename,
 			TQT_MAP,TQL_NORMAL);
 	free_mp_task_t(ot);
+*/
 }
 
 
