@@ -315,7 +315,7 @@ int len,addr_len;
 
 			if ( *last_pri )
 				d_f_ree(*last_pri);
-			*last_pri = ll_copy_str(t->ent[target[1]].pri);
+			*last_pri = ll_copy_str(t->ent[target[i]].pri);
 
 			ep->pri = 0;
 			for ( j = 0 ; j < ACRP_DIR_NOS ; j ++ ) {
