@@ -33,7 +33,7 @@ _main(int argc,char ** argv)
 
 	init_xl(INI_DONTWAITCHI);
 	init_l_favt64();
-	int_handler = 0;
+//	int_handler = 0;
 
 	gc_push(0,0,"main");
 	init_matrix();
@@ -44,6 +44,7 @@ _main(int argc,char ** argv)
 	init_function(gblisp_top_env0,gblisp_top_env1,argc,argv);
 	init_gmx_function(gblisp_top_env0,gblisp_top_env1);
 //	fac_general_info.total_entries = 0;
+	set_xli_flags(-1,XIF_CATCH,XIF_CATCH);
 
 	xl_setup_file(argc,argv);
 
