@@ -26,10 +26,10 @@
 #include	"lock_level.h"
 #include	"memory_debug.h"
 
-
+/*
 #define GVHA_PATH_DEBUG
 #define GVHA_LOADING_STATUS
-
+*/
 
 #define TOLL	5
 #define ACCESS_TIME_LIMIT	20
@@ -3020,7 +3020,9 @@ int err;
 	if ( _dir == 0 )
 		goto sys_error;
 	g_set = search_gvha_set_URL(_dir);
-ss_printf("g_set = %p Rls\n",g_set,_dir);
+#ifdef GVHA_PATH_DEBUG
+ss_printf("g_set = %p R%ls\n",g_set,_dir);
+#endif
 	if ( g_set == 0 )
 		goto sys_error2;
 	_dir_1 = ln_copy_str(std_cm,_dir);
@@ -3031,14 +3033,23 @@ ss_printf("g_set = %p Rls\n",g_set,_dir);
 	d_f_ree(_dir_2);
 	if ( rcode < 0 ) {
 		err_msg = "query parsing";
+#ifdef GVHA_PATH_DEBUG
+ss_printf("ERR %s\n",err_msg);
+#endif
 		goto invalid_url;
 	}
 	if ( q.mode == GVHA_MODE_MOVE && q.pos.target == 0 ) {
 		err_msg = "query parsing target=0 mode undef";
+#ifdef GVHA_PATH_DEBUG
+ss_printf("ERR %s\n",err_msg);
+#endif
 		goto invalid_url;
 	}
 	if ( q.mode & GVHA_NREQ_FRAME_CACHE ) {
 		c = 0;
+#ifdef GVHA_PATH_DEBUG
+ss_printf("NOREQ_FRAME_CACHE\n");
+#endif
 		goto finish2;
 	}
 	if ( out_c ) {
@@ -3534,6 +3545,9 @@ ss_printf("LAST-3 %i = xx\n",get_tid());
 	return ret;
 
 sys_error:
+#ifdef GVHA_PATH_DEBUG
+ss_printf("SYS_ERROR\n");
+#endif
 	return get_error(
 		s->h.file,
 		s->h.line,
@@ -3541,6 +3555,9 @@ sys_error:
 		l_string(std_cm,"gbview/GET"),
 		n_get_string("dir attribute is required"));
 sys_error2:
+#ifdef GVHA_PATH_DEBUG
+ss_printf("SYS_ERROR 2\n");
+#endif
 	return get_error(
 		s->h.file,
 		s->h.line,
@@ -3548,6 +3565,9 @@ sys_error2:
 		l_string(std_cm,"gbview/GET"),
 		n_get_string("corresponding gvha set is not defined (dir)"));
 busy_err:
+#ifdef GVHA_PATH_DEBUG
+ss_printf("BUSY_ERROR 2\n");
+#endif
 	return get_error(
 		s->h.file,
 		s->h.line,
@@ -3555,6 +3575,9 @@ busy_err:
 		l_string(std_cm,"gbview/GET"),
 		n_get_string("home page is BUSY"));
 invalid_url:
+#ifdef GVHA_PATH_DEBUG
+ss_printf("INV URL 2\n");
+#endif
 	return get_error(
 		s->h.file,
 		s->h.line,
