@@ -674,7 +674,7 @@ MATRIX
 
 void init_matrix();
 MATRIX_NODE * get_matrix_node(int * errp,MATRIX * m,
-			INTEGER64 * dim_code,int access,MATRIX_TOKEN*,XL_SEXP**);
+			INTEGER64 * dim_code,int access,MATRIX_TOKEN*,XL_SEXP**,int key);
 INTEGER64 * get_dim_code_from_sexp(MATRIX *,XL_SEXP * );
 XL_SEXP * get_channel_data(MATRIX_NODE * n,int ch,XL_SEXP * s);
 XL_SEXP * matrix_error(char*,XL_SEXP *,int code,XL_SEXP *);
