@@ -36,6 +36,7 @@ typedef struct create_work {
 	int			pri[MI_MODE_MAX][MI_MAX];
 	char			phase_active[MI_MODE_MAX];
 	XL_SEXP *		phase[MI_MODE_MAX][MI_MAX];
+	XLISP_ENV *		env;
 } CREATE_WORK;
 
 typedef struct matrix_param_work {
@@ -75,8 +76,11 @@ typedef struct view_method {
 	void *				work;
 } VIEW_METHOD;
 
+
 typedef struct view_method_tbl {
 	int			mdt_type;
+	int			dimension;
+	int *			divide;
 	MX_STRUCT_BLOCK_TBL *	sb_tbl;
 	int			(*vmt_create)(VIEW_METHOD *,MATRIX_NODE *);
 	void			(*vmt_free)(VIEW_METHOD*);
@@ -113,6 +117,8 @@ MX_ENTRY *
 open_mxread(L_CHAR *neturl,L_CHAR * filename,L_CHAR * key,int phase_mode);
 void
 init_gmx_lib_function(XLISP_ENV * env0,XLISP_ENV * env1);
+void
+check_mx_entry(MX_ENTRY * e);
 
 void init_gmxGetPoint(XLISP_ENV * ,XLISP_ENV * );
 void init_gmxCreate(XLISP_ENV * ,XLISP_ENV * );
@@ -125,6 +131,7 @@ void init_gmxStatus(XLISP_ENV * env0,XLISP_ENV * env1);
 void init_gmxCopy(XLISP_ENV * env0,XLISP_ENV * env1);
 void init_gmxImportUTM(XLISP_ENV * env0,XLISP_ENV * env1);
 void init_gmxCache(XLISP_ENV * env0,XLISP_ENV * env1);
+void init_gmxImportDTED1(XLISP_ENV * env0,XLISP_ENV * env1);
 
 
 extern VIEW_METHOD_TBL **vm_tbl[RT_MAX];
