@@ -81,8 +81,8 @@ void _wakeup_task(unsigned int key,char *file,int line);
 void _i_sleep_task(unsigned int key,SEM s,char *file,int line);
 
 
-#define sleep_task(k,s) _i_sleep_task(k,s,__FILE__,__LINE__)
-#define wakeup_task(k) _wakeup_task(k,__FILE__,__LINE__)
+#define sleep_task(k,s) _i_sleep_task(k,s,(char*)__FILE__,__LINE__)
+#define wakeup_task(k) _wakeup_task(k,(char*)__FILE__,__LINE__)
 
 
 void init_task(int);
@@ -94,7 +94,7 @@ int lock_up_test(SEM);
 D_SEM xx_new_lock(int level,char * file,int line);
 SEM _i_new_lock(int level,char *,int);
 
-#define new_lock(level)	_i_new_lock((level),__FILE__,__LINE__)
+#define new_lock(level)	_i_new_lock((level),(char*)__FILE__,__LINE__)
 /*
 SEM new_lock(int level);
 */
@@ -121,7 +121,7 @@ int create_task(void (*func)(),int data,int pri);
 #ifndef xx_create_task
 int xx_create_task(void (*func)(TKEY),int data,int pri,char*,int);
 #endif
-#define create_task(f,d,p)	xx_create_task(f,d,p,__FILE__,__LINE__)
+#define create_task(f,d,p)	xx_create_task(f,d,p,(char*)__FILE__,__LINE__)
 
 int get_tid();
 HTID _get_tid();
@@ -146,11 +146,15 @@ void sleep_sec(int);
 void _i_unlock_task(SEM,char *,char * ,int);
 void _i_lock_task(SEM,char*,int);
 
-#define lock_task(s)	_i_lock_task((s),__FILE__,__LINE__)
-#define unlock_task(s,str)	_i_unlock_task((s),(str),__FILE__,__LINE__)
+#define lock_task(s)	_i_lock_task((s),(char*)__FILE__,__LINE__)
+#define unlock_task(s,str)	_i_unlock_task((s),(char*)(str),(char*)__FILE__,__LINE__)
 
 void u_exit(int);
 
+void
+set_trace_bit(SEM s);
+
+
 #ifdef __cplusplus
 }
 #endif
