@@ -145,11 +145,12 @@ typedef struct _VgbFlameStatus {
 #define VSF_FLAME_C_FLAME_BASE_RESOLUTION 	(1<<5)
 #define VSF_FLAME_C_FLAME_BASE_UNIT		(1<<6)
 #define VSF_FLAME_C_FLAME_BASE_DISPLAY_MAP_TYPE	(1<<7)
-#define VSF_FLAME_C_CURRENT			(1<<8)
-#define VSF_FLAME_C_LAYERS			(1<<9)
-#define VSF_FLAME_C_PP_RADIUS			(1<<10)
-#define VSF_FLAME_C_TARGET			(1<<11)
-#define VSF_FLAME_C_USE_IWP			(1<<12)
+#define VSF_FLAME_C_FLAME_BASE_GEO_TYPE		(1<<8)
+#define VSF_FLAME_C_CURRENT			(1<<9)
+#define VSF_FLAME_C_LAYERS			(1<<10)
+#define VSF_FLAME_C_PP_RADIUS			(1<<11)
+#define VSF_FLAME_C_TARGET			(1<<12)
+#define VSF_FLAME_C_USE_IWP			(1<<13)
 
 typedef struct _VgbFlameLayers {
 	struct _VgbFlameLayers *	next;
@@ -170,6 +171,7 @@ typedef struct _VgbFlameCoordinateStatus {
 	REAL1		flame_base_resolution;
 	L_CHAR *	flame_base_unit;
 	int		flame_base_display_map_type;
+	int		flame_base_geo_type;
 	WF_ID		current;
 
 	VgbFlameLayers *	layers;
@@ -340,6 +342,10 @@ typedef struct flame_work {
 	VPoint		press;
 	REAL1		press_zoom;
 	int		press_time;
+	
+	I_POINT		action_ptr;
+	int		action_mode;
+	INTEGER64	action_time;
 
 	VPoint		instop_pt;
 	int		instop_time;
@@ -566,8 +572,8 @@ xx_free_wpm_1(WARP_POINT_MENU * m,char * f,int ln);
 extern "C" void
 xx_free_wpm(WARP_POINT_MENU* m,char * f,int ln);
 
-#define free_wpm(w)	xx_free_wpm((w),__FILE__,__LINE__)
-#define free_wpm_1(w)	xx_free_wpm_1((w),__FILE__,__LINE__)
+#define free_wpm(w)	xx_free_wpm((w),(char*)__FILE__,__LINE__)
+#define free_wpm_1(w)	xx_free_wpm_1((w),(char*)__FILE__,__LINE__)
 extern "C" WARP_POINT_MENU*
 copy_wpm(WARP_POINT_MENU* m);
 extern "C" int
