@@ -24,6 +24,7 @@
 
 #define BACKGROUND_COLOR	COL(0x3ff,0x3ff,0x3ff)
 #define BACKGROUND_COLOR_MID	COL(0x200,0x200,0x200)
+#define E1D_FRAME_HEIGHT		100
 
 
 /* win_flame flags */
@@ -71,7 +72,7 @@
 /* for drawing */
 
 #define WFF_DRAW		0x10000000
-
+#define WFF_FLUSH		0x40000000
 
 
 /* win_flame modes */
@@ -86,6 +87,10 @@
 #define W_E2D_POLY		0.3
 #define W_E2D_PLOT		0.01
 
+#define W_E1D_LUSTER		W_E2D_LUSTER
+#define W_E1D_POLY		W_E2D_POLY
+#define W_E1D_PLOT		0.001
+
 #define W_GLOBE_LUSTER		1.2
 #define W_GLOBE_POLY		0.3
 #define W_GLOBE_PLOT		0.01
@@ -102,6 +107,7 @@ typedef struct win_flame_table {
 	short			geo_type;
 		/* equal to GT_T_XX in resource.h */
 	short			wf_type;
+#define WFT_GEN			0
 #define WFT_STD			1
 #define WFT_PLOT		2
 #define WFT_SMALL		3
@@ -186,6 +192,17 @@ typedef struct win_flame_table {
 			struct win_flame *	wf,
 			GB_RECT			r,
 			float			rate);
+	
+	void (*f_calc_pitch)
+		(	GBVIEW_FLAME * gf,
+			int			flag);
+	
+	void (*f_wf_insert_action)
+		(	GBVIEW_FLAME * gf,
+			struct win_flame *	wf,
+			int flags,
+			int move_base_distance,
+			int move_distance);
 } WIN_FLAME_TABLE;
 
 typedef int (*f_zoom_type)
@@ -208,6 +225,14 @@ typedef	int (*f_rotate_type)
 			struct win_flame *	wf,
 			VPOINT *		ix);
 
+typedef	void (*f_wf_insert_action_type)
+
+		(	GBVIEW_FLAME * gf,
+			struct win_flame *	wf,
+			int flags,
+			int move_base_distance,
+			int move_distance);
+
 
 
 typedef struct wf_lock_list {
@@ -215,6 +240,34 @@ typedef struct wf_lock_list {
 	int			tid;
 } WF_LOCK_LIST;
 
+typedef struct wf_work_area {
+	struct wf_work_area *		next;
+	RESOURCE *			r;
+	int				checkout;
+	struct wf_work_area_tbl *	tbl;
+	unsigned			freeflag:1;
+} WF_WORK_AREA;
+
+typedef struct wf_work_area_tbl {
+	void			(*flush_area)(WF_WORK_AREA *);
+	int			(*get_interrested_point)(WF_WORK_AREA *,I_POINT *,int buffer_size);
+	int			(*set_interrested_point)(WF_WORK_AREA *,I_POINT *);
+	void			(*close)(WF_WORK_AREA *);
+} WF_WORK_AREA_TBL;
+
+typedef struct wf_work_area_set {
+	WF_WORK_AREA *		wa_list;
+	int			checkout;
+	unsigned		freeflag:1;
+} WF_WORK_AREA_SET;
+
+typedef struct wf_param_1d {
+	int			y_top;
+	int			y_bottom;
+	int			width;
+	WF_WORK_AREA_SET *	aset;
+} WF_PARAM_1D;
+
 typedef struct win_flame {
 	struct win_flame *	next;
 	WF_ID			id;
@@ -230,11 +283,18 @@ typedef struct win_flame {
 	REAL1			v_reso;
 	MAP_HISTORY *		mh;
 	RESOURCE *		draw;
+
 	unsigned long *		pixels;
+
 	I_RECT			small_rct;
-	
 	unsigned		small_resize:1;
 
+	int			e1d_y_top;
+	int			e1d_y_bottom;
+	int			e1d_top_mergin;
+	int			e1d_bottom_mergin;
+			/* direction of computer axis */
+
 	/* set_current parameter */
 
 	unsigned int		in_base_time;
@@ -256,6 +316,9 @@ typedef struct win_flame {
 #define DR_INTERVAL_MIN 3
 	int			pri_adj;
 	
+	/* work area */
+	WF_WORK_AREA_SET *	wa_set;
+	
 	/* button handling */
 	
 	INTEGER64		hide_time;
@@ -410,6 +473,15 @@ int e2d_resize(	GBVIEW_FLAME * gf,
 int e2d_rotate(	GBVIEW_FLAME * gf,
 		struct win_flame *	wf,
 		VPOINT *		ix);
+void
+e2d_move_wa(WF_WORK_AREA_SET * aset,int dx,int dy);
+void
+e2d_zoom_wa(WF_WORK_AREA_SET * aset);
+void
+e2d_resize_wa(WF_WORK_AREA_SET * aset,int old_w,int old_h,int new_w,int new_h);
+void
+e2d_rotate_wa(WF_WORK_AREA_SET * aset);
+
 void
 e2d_setup_drawrect(GBVIEW_FLAME * gf,WIN_FLAME * wf,GB_RECT,float rate);
 
@@ -485,6 +557,11 @@ int e2d_p_dirty(GBVIEW_FLAME * gf,
 		GB_RECT *		r,
 		int			flags,
 		int			mode);
+int
+e2d_p_resize(GBVIEW_FLAME * gf,WIN_FLAME * wf,int old_w,int old_h);
+
+void
+e2d_calc_pitch(GBVIEW_FLAME * gf,int flag);
 
 
 int globe_move(	GBVIEW_FLAME * gf,
@@ -500,6 +577,8 @@ int globe_move_plot(GBVIEW_FLAME * gf,
 		VPOINT from,
 		VPOINT to,
 		void * ix);
+void
+globe_calc_pitch(GBVIEW_FLAME * gf,int flag);
 
 int _e2d_p_redraw(GBVIEW_FLAME * gf,WIN_FLAME * wf);
 
@@ -556,6 +635,17 @@ int e2d_redraw_rect(
 void regulate_si(WIN_FLAME * wf);
 int inc_xy(int * x,int * y);
 int _e2d_redraw(GBVIEW_FLAME * gf,WIN_FLAME * wf);
+int
+e2d_move_gen(GBVIEW_FLAME * gf,WIN_FLAME * wf,VPOINT from, VPOINT to,void * ix);
+int 
+e2d_zoom_gen
+	(	GBVIEW_FLAME * gf,
+		struct win_flame * 	wf,
+		int			w,
+		int			h,
+		int *			index_x,
+		int *			index_y);
+
 void wf_im_zoom_proc(
 	unsigned long *target,
 	int w,int h,
@@ -568,6 +658,68 @@ int e2d_p_zoom_etc(
 
 void wf_move_si_globe(GBVIEW_FLAME * gf,WIN_FLAME * wf,GLOBE_MOVE_T *t);
 
+void
+e1d_calc_pitch(GBVIEW_FLAME * gf,int flag);
+int
+e1d_zoom(GBVIEW_FLAME * gf,WIN_FLAME * wf,int w,int h,int * ix_x,int * ix_y);
+int
+e1d_redraw(GBVIEW_FLAME * gf,WIN_FLAME * wf);
+int
+e1d_p_redraw(GBVIEW_FLAME * gf,WIN_FLAME * wf);
+void
+e1ds_get_weight(GBVIEW_FLAME * gf,WIN_FLAME * wf);
+int
+e1ds_redraw(GBVIEW_FLAME * gf,WIN_FLAME * wf);
+int
+e1ds_zoom(GBVIEW_FLAME * gf,WIN_FLAME * wf,int w,int h,int * ix_x,int * ix_y);
+int 
+e1d_zoom_gen
+	(	GBVIEW_FLAME * gf,
+		struct win_flame * 	wf,
+		int			w,
+		int			h,
+		int *			index_x,
+		int *			index_y);
+int
+e1d_move_gen(GBVIEW_FLAME * gf,WIN_FLAME * wf,VPOINT from, VPOINT to,void * ix);
+void
+e1d_wf_insert_action_gen(GBVIEW_FLAME * gf,WIN_FLAME * wf,int flags,int mb,int m);
+void
+e1d_wf_insert_action(GBVIEW_FLAME * gf,WIN_FLAME * wf,int flags,int mov_base_distance,int mov_distance);
+void
+e1d_wf_insert_action_plot(GBVIEW_FLAME * gf,WIN_FLAME * wf,int flags,int mov_base_distance,int mov_distance);
+void
+e1d_wf_insert_action_small(GBVIEW_FLAME * gf,WIN_FLAME * wf,int flags,int mov_base_distance,int mov_distance);
+int
+e1d_overlay(GBVIEW_FLAME * gf,WIN_FLAME * wf,OV_ARG * a);
+int
+e1d_overlay_small(GBVIEW_FLAME * gf,WIN_FLAME * wf,OV_ARG * a);
+void
+e1d_setup_drawrect(GBVIEW_FLAME * gf,WIN_FLAME * wf,GB_RECT r,float rate);
+int
+e1d_move(GBVIEW_FLAME * gf,WIN_FLAME * wf,VPOINT from,VPOINT to,
+	 void * _ix);
+int
+e1d_p_move(
+	GBVIEW_FLAME * gf,
+	WIN_FLAME * wf,VPOINT from,VPOINT to,void * _ix);
+int
+e1ds_move(GBVIEW_FLAME * gf,WIN_FLAME * wf,VPOINT from,VPOINT to,
+	 void * _ix);
+int
+e1d_dirty(GBVIEW_FLAME * gf,WIN_FLAME * wf,GB_RECT * r,int flags,int mode);
+
+int
+_e1d_p_redraw(GBVIEW_FLAME * gf,WIN_FLAME * wf);
+
+void
+e2s_move_wa(WF_WORK_AREA * aset,int dx,int dy);
+
+
+int
+globe_move_gen(GBVIEW_FLAME * gf,WIN_FLAME * wf,VPOINT from, VPOINT to,void * ix);
+
+
 int nwf_assert();
 
 void see_lock_d(char * msg,GBVIEW_FLAME * gf,LOCK_D * d,int * ind);
@@ -640,5 +792,33 @@ void
 wf_auth_information(RESOURCE * r);
 void
 insert_lw_service_code_flag_set(RESOURCE * r,XL_SEXP * s);
+void
+_set_move_timer(GBVIEW_FLAME* gf);
+
+void
+wf_close_work_area_set(WF_WORK_AREA_SET * aset);
+int
+wf_checkin_work_area(WF_WORK_AREA * a);
+WF_WORK_AREA *
+wf_checkout_work_area(WF_WORK_AREA_SET * aset,RESOURCE *r);
+WF_WORK_AREA *
+wf_new_work_area(WF_WORK_AREA_SET * aset,WF_WORK_AREA_TBL * tbl,RESOURCE * r,int size);
+void
+wf_work_area_move(WF_WORK_AREA_SET * aset,void (*move_func)(I_POINT * ptr,int len,void * work),void * work);
+void
+wf_work_area_flush(WF_WORK_AREA_SET * aset);
+WF_WORK_AREA_SET *
+wf_new_work_area_set();
+void
+wf_checkout_work_area_set(WF_WORK_AREA_SET * aset);
+void
+wf_checkin_work_area_set(WF_WORK_AREA_SET * aset);
+
+WF_PARAM_1D *
+wf_get_param_1d(GBVIEW_FLAME *,WIN_FLAME *);
+void
+wf_free_param_1d(WF_PARAM_1D*);
+void
+wf_insert_action(GBVIEW_FLAME * gf,WIN_FLAME * wf,int flags);
 
 #endif
