@@ -1180,7 +1180,7 @@ LCZ_SET * p, * q;
 LC_CN * cn;
 L_CHAR * str, * ret, * pp, * qq, * _ret;
 int i;
-	for ( len = 0 ; set[len].lcz != LCC_ERROR && len < length ; len ++ );
+	for ( len = 0 ; set[len].lcz != LCC_ERROR ; len ++ );
 	set_node = d_alloc(sizeof(*set_node)*(len+1));
 	i = 0;
 	for ( p = set, q = set_node ; i < len ; p ++, i ++  ) {
@@ -1389,6 +1389,10 @@ static int fp_ws_init;
 int fp_ws_cnt;
 LC_FONT * ret;
 
+	if ( str == 0 )
+		return 0;
+	if ( *str == 0 )
+		return 0;
 	fp_ws_cnt = fp_ws_init;
 	if ( fp_ws_cnt <= 0 )
 		fp_ws_cnt = 1;
@@ -1442,3 +1446,16 @@ int i;
 	return ret;
 }
 
+
+LCZ_SET *
+get_hit_code(LCZ_SET * set,L_CHAR * str,int len)
+{
+LCZ_SET * ret;
+	for ( ; len > 0 ; str ++ , len -- ) {
+		for ( ret = set ; ret->lcz != LCC_ERROR ; ret ++ )
+			if ( (ret->lcz & ret->mask) == (*str & ret->mask) )
+				return ret;
+	}
+	return 0;
+}
+
