@@ -21,8 +21,8 @@
 #include	"fa_cache.h"
 #include	"memory_debug.h"
 
-#define DATA_MALLOC	d_alloc
-#define DATA_FREE	d_f_ree
+#define DATA_MALLOC	malloc
+#define DATA_FREE	free
 
 void
 fa_print_dump(char*,FAC_ENTRY * e,int ptr,int size);
