@@ -29,7 +29,7 @@ minimum_matrix_init(int argc,char ** argv)
 		gblisp_top_env1,
 		argc,
 		argv);
-	int_handler = 0;
+//	int_handler = 0;
 
 	init_matrix();
 }
