@@ -59,8 +59,9 @@ t->process_node->dim_code[0],
 t->process_node->dim_code[1],
 t->process_node->dim_code[2]);
 */
-
-			ret = (*t->process_node->matrix->p.write_file)(t);
+			if ( t->process_node->status == MS_OK )
+				ret = (*t->process_node->matrix->p.write_file)(t);
+			else	ret = ME_ERR_NODE;
 //ss_printf("END\n");
 		}
 		else 	goto no_suppport;
