@@ -157,7 +157,7 @@ STREAM * ret;
 	ret->chain.write_process = 0;
 
 	lock_task(stream_lock);
-	_s_open(ret,O_RDWR);
+	_s_open(ret,O_RDWR,STT_OTHERS);
 	(*ret->h.cm->close)(0,ret->h.cm_work);
 	ret->h.cm = &extucs4_cm;
 	ret->h.cm_work = (*ret->h.cm->open)();
