@@ -198,7 +198,7 @@ gvagent_redraw(FLAME_SWITCH * sw)
 }
 
 XL_SEXP * 
-n_get_symbol_with_fid(const FLAME_SWITCH * sw, char * name)
+n_get_symbol_with_fid(const FLAME_SWITCH * sw,const char * name)
 {
 	XL_SEXP * ret = n_get_symbol(name);
 	char buf[20];
@@ -208,7 +208,7 @@ n_get_symbol_with_fid(const FLAME_SWITCH * sw, char * name)
 }
 
 XL_SEXP * 
-n_get_symbol_with_format(const FLAME_SWITCH * sw, char * name)
+n_get_symbol_with_format(const FLAME_SWITCH * sw,const char * name)
 {
 	XL_SEXP * ret = n_get_symbol_with_fid(sw,name);
 	if ( sw->gv_redraw_format )
