@@ -332,6 +332,14 @@ vobj_Layout()
 	return 0;
 }
 
+void
+vobj_quit_loop()
+{
+	if ( vobject_quit() == 0 )
+		for ( ; ; )
+			sleep_sec(1);
+}
+
 void
 init_vobj_utils(XLISP_ENV *env)
 {
@@ -494,7 +502,7 @@ vobj_status_flag_from_fs(XL_SEXP *arg, XL_SYM_FIELD *sf, int *out_flags,
 // -------- V_ER_xxx --> XL_SEXP --------
 
 XL_SEXP *
-get_ex_flags_pos(int flags,char * msg)
+get_ex_flags_pos(int flags,const char * msg)
 {
 XL_SEXP * ret;
 	ret = 0;
@@ -603,7 +611,7 @@ XL_SEXP * ret;
 
 
 XL_SEXP *
-vobj_get_error(VExError err, XL_SEXP *arg,char*msg)
+vobj_get_error(VExError err, XL_SEXP *arg,const char*msg)
 {
 L_CHAR * func;
 XL_SEXP * sym;
@@ -932,7 +940,7 @@ get_vsat(XLISP_ENV * arg_env,L_CHAR * v)
 		}
 		else	_ee = arg_env;
 		if ( sf_func == 0 )
-			sf_func = nl_copy_str(std_cm,"get_vsat");
+			sf_func = nl_copy_str(std_cm,(char*)"get_vsat");
 		vsat = (VSysArgTranslator*)d_alloc(sizeof(*vsat));
 		memset(vsat,0,sizeof(*vsat));
 		vsat->env = _ee;
@@ -990,7 +998,7 @@ get_sts_from_sf(XLISP_ENV * arg_env,VObjectStatus *s,int flags, XL_SYM_FIELD *sf
 			}							\
 			else	_ee = arg_env;					\
 			if ( sf_func == 0 )					\
-				sf_func = nl_copy_str(std_cm,#value);		\
+				sf_func = nl_copy_str(std_cm,(char*)#value);	\
 			vsat = (VSysArgTranslator*)d_alloc(sizeof(*vsat));	\
 			memset(vsat,0,sizeof(*vsat));				\
 			vsat->env = _ee;					\
@@ -1197,8 +1205,17 @@ get_default_sts_from_symbol(XLISP_ENV * env,VObjectStatus * sts,
 {
 XL_SEXP * _sts;
 	_sts = eval(env,n_get_symbol("VObjectStatus"));
-	if ( get_type(_sts) != XLT_SYMBOL )
+retry:
+	switch ( get_type(_sts) ) {
+	case XLT_PAIR:
+		_sts = car(_sts);
+		goto retry;
+		break;
+	case XLT_SYMBOL:
+		break;
+	default:
 		return 0;
+	}
 	return get_sts_from_sf(env,sts,0,_sts->symbol.field,fl);
 }
 
@@ -1366,7 +1383,7 @@ VObjectStatus sts;
 
 typedef struct modal_event_func_tbl {
 	int			type;
-	char *			name;
+	const char *		name;
 } MODAL_EVENT_FUNC_TBL;
 
 typedef struct modal_event_arg {
@@ -1428,7 +1445,8 @@ MODAL_EVENT_ARG * ag;
 	ag = (MODAL_EVENT_ARG*)d_alloc(sizeof(*ag)*DIO_MAX);
 	memset(ag,0,sizeof(*ag)*DIO_MAX);
 	for ( i = 0 ; modal_event_func_table[i].name ; i ++ ) {
-		id = vobj_get_object_by_name(ret,nm=nl_copy_str(std_cm,modal_event_func_table[i].name),0);
+		id = vobj_get_object_by_name(ret,nm=nl_copy_str(std_cm,
+				(char*)modal_event_func_table[i].name),0);
 		d_f_ree(nm);
 		if ( get_type(id) != XLT_INTEGER )
 			continue;
