@@ -23,7 +23,7 @@ extern "C" {
 #include	"memory_debug.h"
 #include	"lock_level.h"
 
-void er_panic(char*);
+
 
 } // extern "C"
 
@@ -58,7 +58,7 @@ V_CALLBACK_D(tv_bc_destroy_handler);
 SEM vxl_cf_lock;
 int vxl_cf_lock_cnt;
 int vxl_cf_lock_tid;
-char * vxl_cf_lock_file;
+const char * vxl_cf_lock_file;
 int vxl_cf_lock_line;
 
 extern "C" void
@@ -68,7 +68,7 @@ init_VxlTreeView()
 }
 
 void
-do_vxl_cf_lock(char * f,int ln)
+do_vxl_cf_lock(const char * f,int ln)
 {
 int tid;
 	tid = get_tid();
@@ -697,7 +697,7 @@ VxlTreeView * cf_p;
 	if ( cf_p ) {
 		cf_p->delete_cascade_focus(this);
 	}
-	vm_lock((VMacro*)(this),__FILE__,__LINE__);
+	vm_lock((VMacro*)(this),(char*)__FILE__,__LINE__);
 	for ( ; tv_w.bc ; ) {
 		bc = tv_w.bc;
 		tv_w.bc = bc->next;
@@ -1424,7 +1424,7 @@ VxlTreeView * c;
 
 
 int
-VxlTreeView::_cf_lock(char*f,int ln)
+VxlTreeView::_cf_lock(const char*f,int ln)
 {
 int er;
 VxlTreeView * c, * c2;
