@@ -1123,7 +1123,7 @@ void call__main()
 {
 	int argc = 1;
 	char *argv[2];
-	argv[0] = copy_str("VApplication");
+	argv[0] = copy_str((char*)"VApplication");
 
 	char *path = v_choose_file(l_string(std_cm,"Open XL File"));
 	if ( path ) {
