@@ -743,24 +743,10 @@ XL_SEXP *
 eval(XLISP_ENV * env,XL_SEXP * s)
 {
 XL_SEXP * r;
-XL_INTERPRETER * xli;
 XL_SEXP * ret;
-	xli = get_my_xli();
-	if ( xli && (xli->flags & XIF_CANCEL) ) {
-		return get_error(
-			s->h.file,
-			s->h.line,
-			XLE_SYSTEM_CANCEL,
-			l_string(std_cm,"eval"),
-			list(	n_get_string("execution is canceled"),
-				s,
-				0));
-	}
-	if ( break_check ) {
-		r = (*break_check)(s);
-		if ( get_type(r) == XLT_ERROR )
-			return r;
-	} 
+	r = do_break_check(s);
+	if ( get_type(r) == XLT_ERROR )
+		return r;
 	switch ( get_type(s) ) {
 	case XLT_PAIR:
 		ret = eval_pair(env,s);
