@@ -1277,6 +1277,7 @@ connect_sv:
 				"GET AGENT: cannot connect the server"),
 				get_string(get_url_str2(u)),
 				get_integer(iid,0),
+				get_integer((int)getpid(),0),
 				-1)
 				);
 		return 0;
@@ -1710,77 +1711,37 @@ NPROXY_DIRECT_SERVER * ret;
 	return ret;
 }
 
-
 XL_SEXP *
-remote_session_xlp(
+native_proxy_send_session(
+	int * mode,
 	XLISP_ENV * env,
 	int id,
 	URL * u,
-	L_CHAR * _a_agent,
-	L_CHAR * _a_login_mode,
-	L_CHAR * _a_center_cmd,
+	L_CHAR * a_agent,
+	L_CHAR * a_login_mode,
+	L_CHAR * a_center_cmd,
 	XL_SEXP * cmd,
 	XL_FILE * f,
 	int ln,
 	int session_lock_enable,
 	REMOTE_SESSION_OPT * opt)
 {
-NPROXY_DIRECT_SERVER * is;
-XL_SEXP * send_query, * ret;
+XL_SEXP * ret;
+XL_SEXP * send_query;
 char buf[20];
-L_CHAR * a_agent,* a_login_mode,* a_center_cmd;
-int pri;
+NPROXY_DIRECT_SERVER * is;
 
-	pri = push_pri_pctl(&xli_lock_ctl);
-
-	if ( u->agent )
-		a_agent = ll_copy_str(u->agent);
-	else if ( _a_agent )
-		a_agent = ll_copy_str(_a_agent);
-	else	a_agent = 0;
-	if ( _a_login_mode )
-		a_login_mode = ll_copy_str(_a_login_mode);
-	else	a_login_mode = 0;
-	if ( _a_center_cmd )
-		a_center_cmd = ll_copy_str(_a_center_cmd);
-	else	a_center_cmd = 0;
-
-	if ( native_proxy_session == 0 ) {
-		ret = _remote_session(
-				env,
-				id,
-				u,
-				a_agent,
-				a_login_mode,
-				a_center_cmd,
-				cmd,
-				f,
-				ln,
-				session_lock_enable,
-				0,0,opt);
-		goto end;
-	}
 	is = search_direct_server(u->server);
 	if ( is ) {
-		ret = _remote_session(
-				env,
-				id,
-				u,
-				a_agent,
-				a_login_mode,
-				a_center_cmd,
-				cmd,
-				f,
-				ln,
-				session_lock_enable,
-				0,0,opt);
-		goto end;
+		*mode = NPS_DIRECT;
+		return 0;
 	}
 
+	*mode = NPS_PROXY;
 	ret = setup_session_proxy(id,f,ln);
 	if ( get_type(ret) == XLT_ERROR )
 		goto end;
-	if ( get_type(ret) != XLT_NULL )
+	if ( get_type(ret) != XLT_NULL ) {
 		ret = _remote_session(
 				gblisp_top_env0,
 				native_proxy_session,
@@ -1794,6 +1755,7 @@ int pri;
 				0,
 				0,
 				id,opt);
+	}
 	if ( ret && ret->h.type == XLT_ERROR )
 		goto end;
 
@@ -1843,6 +1805,87 @@ int pri;
 			ln,
 			session_lock_enable,
 			0,id,opt);
+
+end:
+	return ret;
+}
+
+
+XL_SEXP *
+remote_session_xlp(
+	XLISP_ENV * env,
+	int id,
+	URL * u,
+	L_CHAR * _a_agent,
+	L_CHAR * _a_login_mode,
+	L_CHAR * _a_center_cmd,
+	XL_SEXP * cmd,
+	XL_FILE * f,
+	int ln,
+	int session_lock_enable,
+	REMOTE_SESSION_OPT * opt)
+{
+XL_SEXP  * ret;
+L_CHAR * a_agent,* a_login_mode,* a_center_cmd;
+int pri;
+int mode;
+
+	pri = push_pri_pctl(&xli_lock_ctl);
+
+	if ( u->agent )
+		a_agent = ll_copy_str(u->agent);
+	else if ( _a_agent )
+		a_agent = ll_copy_str(_a_agent);
+	else	a_agent = 0;
+	if ( _a_login_mode )
+		a_login_mode = ll_copy_str(_a_login_mode);
+	else	a_login_mode = 0;
+	if ( _a_center_cmd )
+		a_center_cmd = ll_copy_str(_a_center_cmd);
+	else	a_center_cmd = 0;
+
+	if ( native_proxy_session == 0 ) {
+		ret = _remote_session(
+				env,
+				id,
+				u,
+				a_agent,
+				a_login_mode,
+				a_center_cmd,
+				cmd,
+				f,
+				ln,
+				session_lock_enable,
+				0,0,opt);
+		goto end;
+	}
+	ret = native_proxy_send_session(
+		&mode,
+		env,
+		id,
+		u,
+		a_agent,
+		a_login_mode,
+		a_center_cmd,
+		cmd,
+		f,
+		ln,
+		session_lock_enable,
+		opt);
+	if ( mode == NPS_DIRECT ) {
+		ret = _remote_session(
+				env,
+				id,
+				u,
+				a_agent,
+				a_login_mode,
+				a_center_cmd,
+				cmd,
+				f,
+				ln,
+				session_lock_enable,
+				0,0,opt);
+	}
 end:
 	if ( a_agent )
 		d_f_ree(a_agent);
